@@ -1,10 +1,13 @@
 __title__ = 'magna'
 __description__ = 'Magna is a collection of commands that I frequently use in bioinformatics and day-to-day life.'
 __url__ = 'https://github.com/aaronmussig/magna'
-__version__ = '3.4.0'
+__version__ = '4.1.0'
 __author__ = 'Aaron Mussig'
 __author_email__ = 'aaronmussig@gmail.com'
 __license__ = 'GNU AGPLv3'
 __bug_url__ = 'https://github.com/aaronmussig/magna'
 __doc_url__ = 'https://github.com/aaronmussig/magna'
 __src_url__ = 'https://github.com/aaronmussig/magna'
+
+# Import the rust binary
+from .magna import *
